@@ -1,7 +1,9 @@
 package App::metasyn;
 
-our $DATE = '2021-03-03'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-06-26'; # DATE
+our $DIST = 'App-metasyn'; # DIST
+our $VERSION = '0.008'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,13 +32,14 @@ This script is an alternative front-end for <pm:Acme::MetaSyntactic>. Compared
 to the official CLI <prog:meta>, this CLI currently does not retrieve
 themes/names remotely but:
 
-* provides shell completion;
+* provides shell completion (but see <pm:App::ShellCompleter::meta> to add tab
+  completion for the official CLI);
 * provides an option to shuffle list of themes/categories/names returned;
 * makes it easy to print all names in a theme;
 * makes it easy to print all (or some) categories in a theme.
 
 This CLI is more geared towards listing all themes/names/categories instead of
-picking one.
+picking random ones.
 
 _
     args => {
@@ -81,7 +84,7 @@ _
             'x.doc.max_result_lines' => 10,
         },
         {
-            summary => 'Return a single random name from the default theme (equivalent of: meta)',
+            summary => 'Return a single random name from the default theme (equivalent to: "meta")',
             argv => [qw/-n1 -R/],
         },
         {
@@ -90,11 +93,11 @@ _
             'x.doc.max_result_lines' => 10,
         },
         {
-            summary => 'List all names from a category of a theme in random order, return only 3 (equivalent of: meta christmas/elf 3)',
+            summary => 'List all names from a category of a theme in random order, return only 3 (equivalent to: "meta christmas/elf 3")',
             argv => [qw(christmas/elf -n3 -R)],
         },
         {
-            summary => 'Return a single random name from a theme (equivalent of: meta christmas)',
+            summary => 'Return a single random name from a theme (equivalent to: "meta christmas")',
             argv => [qw(christmas -n1 -R)],
         },
         {
@@ -104,12 +107,12 @@ _
 
         # listing themes
         {
-            summary => 'List all installed themes (equivalent of: meta --themes)',
+            summary => 'List all installed themes (equivalent to: "meta --themes")',
             argv => [qw/-l/],
             'x.doc.max_result_lines' => 10,
         },
         {
-            summary => 'List 3 random themes (equivalent of: meta --themes | shuf | head -n3)',
+            summary => 'List 3 random themes (equivalent to: "meta --themes | shuf | head -n3")',
             argv => [qw/-l -n3 -R/],
         },
         {
@@ -214,7 +217,7 @@ App::metasyn - Alternative front-end to Acme::MetaSyntactic
 
 =head1 VERSION
 
-This document describes version 0.007 of App::metasyn (from Perl distribution App-metasyn), released on 2021-03-03.
+This document describes version 0.008 of App::metasyn (from Perl distribution App-metasyn), released on 2021-06-26.
 
 =head1 SYNOPSIS
 
@@ -227,7 +230,7 @@ Use the included script L<metasyn>.
 
 Usage:
 
- metasyn(%args) -> [status, msg, payload, meta]
+ metasyn(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Alternative front-end to Acme::MetaSyntactic.
 
@@ -259,13 +262,13 @@ Result:
    {},
  ]
 
-=item * Return a single random name from the default theme (equivalent of: meta):
+=item * Return a single random name from the default theme (equivalent to: "meta"):
 
- metasyn( number => 1, shuffle => 1); # -> [200, "OK", ["kees"], {}]
+ metasyn(number => 1, shuffle => 1); # -> [200, "OK", ["mies"], {}]
 
 =item * List all names from a theme:
 
- metasyn( theme => "christmas");
+ metasyn(theme => "christmas");
 
 Result:
 
@@ -287,25 +290,25 @@ Result:
    {},
  ]
 
-=item * List all names from a category of a theme in random order, return only 3 (equivalent of: meta christmasE<sol>elf 3):
+=item * List all names from a category of a theme in random order, return only 3 (equivalent to: "meta christmasE<sol>elf 3"):
 
- metasyn( theme => "christmas/elf", number => 3, shuffle => 1);
+ metasyn(theme => "christmas/elf", number => 3, shuffle => 1);
 
 Result:
 
- [200, "OK", ["bushy", "snowball", "wunorse"], {}]
+ [200, "OK", ["bushy", "pepper", "sugarplum"], {}]
 
-=item * Return a single random name from a theme (equivalent of: meta christmas):
+=item * Return a single random name from a theme (equivalent to: "meta christmas"):
 
- metasyn( theme => "christmas", number => 1, shuffle => 1); # -> [200, "OK", ["donner"], {}]
+ metasyn(theme => "christmas", number => 1, shuffle => 1); # -> [200, "OK", ["twinkle"], {}]
 
 =item * Return a single random name from a random theme:
 
- metasyn( number => 1, random_theme => 1, shuffle => 1); # -> [200, "OK", ["meu"], {}]
+ metasyn(number => 1, random_theme => 1, shuffle => 1); # -> [200, "OK", ["sxga"], {}]
 
-=item * List all installed themes (equivalent of: meta --themes):
+=item * List all installed themes (equivalent to: "meta --themes"):
 
- metasyn( action => "list-themes");
+ metasyn(action => "list-themes");
 
 Result:
 
@@ -317,7 +320,7 @@ Result:
      "afke",
      "alice",
      "alphabet",
- # ...snipped 138 lines for brevity...
+ # ...snipped 136 lines for brevity...
      "viclones",
      "wales_towns",
      "weekdays",
@@ -327,17 +330,17 @@ Result:
    {},
  ]
 
-=item * List 3 random themes (equivalent of: meta --themes E<verbar> shuf E<verbar> head -n3):
+=item * List 3 random themes (equivalent to: "meta --themes E<verbar> shuf E<verbar> head -n3"):
 
- metasyn( action => "list-themes", number => 3, shuffle => 1);
+ metasyn(action => "list-themes", number => 3, shuffle => 1);
 
 Result:
 
- [200, "OK", ["contrade", "display_resolution", "tld"], {}]
+ [200, "OK", ["foo", "christmas", "simpsons"], {}]
 
 =item * List all installed themes, along with all their categories:
 
- metasyn( action => "list-themes", categories => 1);
+ metasyn(action => "list-themes", categories => 1);
 
 Result:
 
@@ -349,7 +352,7 @@ Result:
      "afke",
      "alice",
      "alphabet/en",
- # ...snipped 2211 lines for brevity...
+ # ...snipped 2221 lines for brevity...
      "zodiac/Chinese",
      "zodiac/Vedic",
      "zodiac/Western",
@@ -361,7 +364,7 @@ Result:
 
 =item * List all categories from a theme:
 
- metasyn( theme => "christmas", categories => 1);
+ metasyn(theme => "christmas", categories => 1);
 
 Result:
 
@@ -369,11 +372,11 @@ Result:
 
 =item * List 2 categories from a theme, in random order:
 
- metasyn( theme => "christmas", categories => 1, number => 2, shuffle => 1);
+ metasyn(theme => "christmas", categories => 1, number => 2, shuffle => 1);
 
 Result:
 
- [200, "OK", ["snowman", "santa"], {}]
+ [200, "OK", ["reindeer", "snowman"], {}]
 
 =back
 
@@ -383,7 +386,8 @@ themes/names remotely but:
 
 =over
 
-=item * provides shell completion;
+=item * provides shell completion (but see L<App::ShellCompleter::meta> to add tab
+completion for the official CLI);
 
 =item * provides an option to shuffle list of themes/categories/names returned;
 
@@ -394,7 +398,7 @@ themes/names remotely but:
 =back
 
 This CLI is more geared towards listing all themes/names/categories instead of
-picking one.
+picking random ones.
 
 This function is not exported.
 
@@ -421,12 +425,12 @@ Limit only return this number of results.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -440,7 +444,7 @@ Source repository is at L<https://github.com/perlancar/perl-App-metasyn>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-metasyn/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-metasyn>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
